@@ -10,21 +10,25 @@ fn main() {
             writeln!(
                 &mut io::stderr(),
                 "Invalid option. Usage: `stream [-d|-1..-21]`"
-            ).unwrap();
+            )
+            .unwrap();
         }
         Some(ref option) if option == "-d" => decompress(),
-        Some(ref option) => if option.starts_with('-') {
-            let level = match i32::from_str(&option[1..]) {
-                Ok(level) => level,
-                Err(e) => panic!("Error parsing compression level: {}", e),
-            };
-            compress(level);
-        } else {
-            writeln!(
-                &mut io::stderr(),
-                "Invalid option. Usage: `stream [-d|-1..-21]`"
-            ).unwrap();
-        },
+        Some(ref option) => {
+            if option.starts_with('-') {
+                let level = match i32::from_str(&option[1..]) {
+                    Ok(level) => level,
+                    Err(e) => panic!("Error parsing compression level: {}", e),
+                };
+                compress(level);
+            } else {
+                writeln!(
+                    &mut io::stderr(),
+                    "Invalid option. Usage: `stream [-d|-1..-21]`"
+                )
+                .unwrap();
+            }
+        }
     }
 }
 
